@@ -2,6 +2,7 @@ import re,threading,os,shutil,requests,asyncio,time,subprocess,json,glob,sys,log
 from datetime import timedelta
 from datetime import datetime
 from typing import *
+from .hash_utils import *
 from .json_utils import (unified_json_loader,
                          find_keys,
                          get_key_values_from_path,
@@ -20,18 +21,20 @@ from .json_utils import (unified_json_loader,
                          update_dict_value,
                          get_all_key_values,
                          get_json_data,
-                         get_file_path,
                          safe_json_dumps,
                          safe_json_loads,
                          read_from_json,
-                         safe_read_from_json,
                          safe_load_from_json,
                          safe_load_from_file,
                          safe_json_reads,
+                         safe_read_from_json,
                          safe_dump_to_file,
                          safe_dump_to_json,
                          safe_write_to_json,
-                         safe_write_to_file
+                         safe_write_to_file,
+                         safe_save_updated_json_data,
+                         get_result_from_data,
+                         flatten_json
                          )
 from .read_write_utils import (read_from_file,
                                write_to_file)
@@ -66,7 +69,10 @@ from .path_utils import (get_file_create_time,
                          get_dirlist,
                          get_content,
                          is_directory_in_paths,
-                         make_dirs
+                         make_dirs,
+                         remove_directory,
+                         remove_path,
+                         get_file_parts
                          )
 from .list_utils import (get_highest_value_obj,
                          make_list,
@@ -74,7 +80,8 @@ from .list_utils import (get_highest_value_obj,
                          get_actual_number,
                          compare_lists,
                          get_symetric_difference,
-                         list_set)
+                         list_set,
+                         make_list_it)
 from .time_utils import (get_time_stamp,
                          get_sleep,
                          sleep_count_down,
@@ -83,11 +90,14 @@ from .time_utils import (get_time_stamp,
                          format_timestamp,
                          timestamp_to_milliseconds,
                          parse_timestamp,
-                         get_time_now_iso)
+                         get_time_now_iso,
+                         is_valid_time)
 from .string_clean import (eatInner,
                            eatAll,
                            eatOuter,
-                           url_join)
+                           url_join,
+                           capitalize
+                           )
 from .type_utils import (make_bool,
                          T_or_F_obj_eq,
                          is_number,
@@ -97,7 +107,21 @@ from .type_utils import (make_bool,
                          get_all_types,
                          get_media_types,
                          get_all_file_types,
-                         is_media_type)
+                         is_media_type,
+                         get_bool_response,
+                         get_mime_type,
+                         get_media_exts,
+                         if_true_get_string,
+                         find_for_string,
+                         is_strings_in_string,
+                         get_alphabet_str,
+                         get_alphabet_upper_str,
+                         get_alphabet_comp_str,
+                         get_numbers,
+                         get_numbers_comp,
+                         is_any_instance,
+                         break_string
+                         )
 from .math_utils import (convert_to_percentage,
                          exponential,
                          get_percentage,
@@ -113,8 +137,14 @@ from .history_utils import HistoryManager
 from .abstract_classes import *
 from .parse_utils import (num_tokens_from_string,
                           chunk_source_code,
-                          chunk_any_to_tokens)
+                          chunk_any_to_tokens,
+                          detect_language_from_text,
+                          chunk_by_language_context,
+                          search_code)
 
 from .log_utils import get_logFile,print_or_log
 from .error_utils import try_func
-from .class_utils import alias
+from .class_utils import alias,get_class_inputs
+
+
+
