@@ -60,6 +60,59 @@ import os
 from typing import Union
 from .path_utils import get_all_item_paths,get_files
 from .list_utils import make_list
+MIME_TYPES_JS = media_types = {
+        'image': {
+            '.jpg': 'image/jpeg',
+            '.jpeg': 'image/jpeg',
+            '.png': 'image/png',
+            '.gif': 'image/gif',
+            '.bmp': 'image/bmp',
+            '.tiff': 'image/tiff',
+            '.webp': 'image/webp',
+            '.svg': 'image/svg+xml'
+        },
+        'video': {
+            '.mp4': 'video/mp4',
+            '.avi': 'video/x-msvideo',
+            '.mov': 'video/quicktime',
+            '.wmv': 'video/x-ms-wmv',
+            '.flv': 'video/x-flv',
+            '.mkv': 'video/x-matroska',
+            '.webm': 'video/webm'
+        },
+        'audio': {
+            '.mp3': 'audio/mpeg',
+            '.wav': 'audio/wav',
+            '.ogg': 'audio/ogg',
+            '.flac': 'audio/flac',
+            '.aac': 'audio/x-aac',
+            '.m4a': 'audio/mp4'
+        },
+        'document': {
+            '.pdf': 'application/pdf',
+            '.doc': 'application/msword',
+            '.docx': 'application/vnd.openxmlformats-officedocument.wordprocessingml.document',
+            '.txt': 'text/plain',
+            '.rtf': 'application/rtf'
+        },
+        'presentation': {
+            '.ppt': 'application/vnd.ms-powerpoint',
+            '.pptx': 'application/vnd.openxmlformats-officedocument.presentationml.presentation'
+        },
+        'spreadsheet': {
+            '.xls': 'application/vnd.ms-excel',
+            '.xlsx': 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet',
+            '.csv': 'text/csv'
+        }
+    }
+MEDIA_TYPES = {
+            'image': {'.svg', '.bmp', '.tiff', '.jpg', '.png', '.webp', '.gif', '.jpeg'},
+            'video': {'.mp4', '.webm', '.avi', '.wmv', '.flv', '.mov', '.mkv'},
+            'audio': {'.flac', '.ogg', '.wav', '.m4a', '.aac', '.mp3'},
+            'document': {'.rtf', '.txt', '.doc', '.pdf', '.docx'},
+            'presentation': {'.pptx', '.ppt'},
+            'spreadsheet': {'.xls', '.xlsx', '.csv'}
+        }
 def get_all_key_values(keys=None,dict_obj=None):
     keys = keys or []
     dict_obj = dict_obj or {}
@@ -69,37 +122,50 @@ def get_all_key_values(keys=None,dict_obj=None):
         if values:
             new_dict_obj[key]=values
     return new_dict_obj
+def get_all_key_values(keys=None,dict_obj=None):
+    keys = keys or []
+    dict_obj = dict_obj or {}
+    new_dict_obj = {}
+    for key in keys:
+        values = dict_obj.get(key)
+        if values:
+            new_dict_obj[key]=values
+    return new_dict_obj
+
 def get_media_types(types=None):
-    types = make_list(types) or []
-    media_types = {
-        'image': {'.jpg', '.jpeg', '.png', '.gif', '.bmp', '.tiff', '.webp', '.svg'},
-        'video': {'.mp4', '.avi', '.mov', '.wmv', '.flv', '.mkv', '.webm'},
-        'audio': {'.mp3', '.wav', '.ogg', '.flac', '.aac', '.m4a'},
-        'document': {'.pdf', '.doc', '.docx', '.txt', '.rtf'},
-        'presentation': {'.ppt', '.pptx'},
-        'spreadsheet': {'.xls', '.xlsx', '.csv'}
-    }
+    types = make_list(types or [])
+    media_types = MEDIA_TYPES
     if types:
-        return get_all_key_values(keys=types,dict_obj=media_types)
+        media_types = get_all_key_values(keys=types,dict_obj=MEDIA_TYPES)
     return media_types
-def confirm_type(file_path,media_types=None):
-    media_types = media_types or get_media_types()
-    dirname = os.path.dirname(file_path)
-    basename = os.path.basename(file_path)
-    filename,ext = os.path.splitext(basename)
+def get_media_exts(types=None):
+    all_exts = []
+    types = make_list(types or [])
+    for typ in types:
+        exts = MEDIA_TYPES.get(str(typ)) or []
+        if exts:
+            all_exts+=list(exts)
+    return all_exts
+def confirm_type(file_path=None,media_types=None,ext=None):
+    media_types = media_types or get_media_types('video')
+    ext = ext or os.path.splitext(file_path)[-1]
     for typ,exts in media_types.items():
-         if ext in exts:
+        if ext in exts:
              return typ
-def is_media_type(file_path,media_types=None):
+def is_media_type(file_path,media_types=None,ext=None):
     media_types = make_list(media_types or [])
-    basename = os.path.basename(file_path)
-    filename,ext=os.path.splitext(basename)
+    ext = ext or os.path.splitext(file_path)[-1]
     media_types_js = get_media_types()
     for media_type in media_types:
         exts = media_types_js.get(media_type)
         if exts and ext in exts:
             return True
     return False
+def get_mime_type(file_path):
+    ext = os.path.splitext(file_path)[-1]
+    media = confirm_type(file_path=file_path,ext=ext)
+    mime_type = MIME_TYPES_JS.get(media,{}).get(ext) or 'application/octet-stream'
+    return mime_type
 def get_all_types(types=None,directory=None):
     if not directory or not os.path.isdir(directory):
         return []
@@ -144,7 +210,7 @@ def get_type(obj:any) -> any:
         obj = str(obj)
     return obj
 
-def is_number(obj:any) -> bool:
+def is_instance(obj:any,typ:any) -> bool:
     """
     Checks whether the input object can be represented as a number.
 
@@ -154,11 +220,20 @@ def is_number(obj:any) -> bool:
     Returns:
         bool: True if the object can be represented as a number, False otherwise.
     """
+    boolIt = False
     try:
-        float(obj)
+        boolIt = isinstance(obj, typ)
+        return boolIt
+    except:
+        return boolIt
+
+def is_number(s):
+    try:
+        float(s)
         return True
-    except (TypeError, ValueError):
+    except:
         return False
+
 def is_object(obj:any) -> bool:
     """
     Checks whether the input object is of type 'object'.
@@ -169,7 +244,7 @@ def is_object(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'object', False otherwise.
     """
-    return isinstance(obj, object)
+    return is_instance(obj, object)
 def is_str(obj:any) -> bool:
     """
     Checks whether the input object is of type 'str'.
@@ -180,7 +255,7 @@ def is_str(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'str', False otherwise.
     """
-    return isinstance(obj, str)
+    return is_instance(obj, str)
 def is_int(obj:any) -> bool:
     """
     Checks whether the input object is of type 'int'.
@@ -191,7 +266,7 @@ def is_int(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'int', False otherwise.
     """
-    return isinstance(obj, int)
+    return is_instance(obj, int)
 def is_float(obj:any) -> bool:
     """
     Checks whether the input object is of type 'float'.
@@ -202,7 +277,7 @@ def is_float(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'float', False otherwise.
     """
-    return isinstance(obj, float)
+    return is_instance(obj, float)
 def is_bool(obj:any) -> bool:
     """
     Checks whether the input object is of type 'bool'.
@@ -213,7 +288,7 @@ def is_bool(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'bool', False otherwise.
     """
-    return isinstance(obj, bool)
+    return is_instance(obj, bool)
 
 
 def is_list(obj:any) -> bool:
@@ -226,7 +301,7 @@ def is_list(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'list', False otherwise.
     """
-    return isinstance(obj, list)
+    return is_instance(obj, list)
 def is_tuple(obj:any) -> bool:
     """
     Checks whether the input object is of type 'tuple'.
@@ -237,7 +312,7 @@ def is_tuple(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'tuple', False otherwise.
     """
-    return isinstance(obj, tuple)
+    return is_instance(obj, tuple)
 def is_set(obj:any) -> bool:
     """
     Checks whether the input object is of type 'set'.
@@ -248,7 +323,7 @@ def is_set(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'set', False otherwise.
     """
-    return isinstance(obj, set)
+    return is_instance(obj, set)
 def is_dict(obj:any) -> bool:
     """
     Checks whether the input object is of type 'dict'.
@@ -259,7 +334,7 @@ def is_dict(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'dict', False otherwise.
     """
-    return isinstance(obj, dict)
+    return is_instance(obj, dict)
 def is_frozenset(obj:any) -> bool:
     """
     Checks whether the input object is of type 'frozenset'.
@@ -270,7 +345,7 @@ def is_frozenset(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'frozenset', False otherwise.
     """
-    return isinstance(obj, frozenset)
+    return is_instance(obj, frozenset)
 def is_bytearray(obj:any) -> bool:
     """
     Checks whether the input object is of type 'bytearray'.
@@ -281,7 +356,7 @@ def is_bytearray(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'bytearray', False otherwise.
     """
-    return isinstance(obj, bytearray)
+    return is_instance(obj, bytearray)
 def is_bytes(obj:any) -> bool:
     """
     Checks whether the input object is of type 'bytes'.
@@ -292,7 +367,7 @@ def is_bytes(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'bytes', False otherwise.
     """
-    return isinstance(obj, bytes)
+    return is_instance(obj, bytes)
 def is_memoryview(obj:any) -> bool:
     """
     Checks whether the input object is of type 'memoryview'.
@@ -303,7 +378,7 @@ def is_memoryview(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'memoryview', False otherwise.
     """
-    return isinstance(obj, memoryview)
+    return is_instance(obj, memoryview)
 def is_range(obj:any) -> bool:
     """
     Checks whether the input object is
@@ -316,7 +391,7 @@ def is_range(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'range', False otherwise.
     """
-    return isinstance(obj, range)
+    return is_instance(obj, range)
 def is_enumerate(obj:any) -> bool:
     """
     Checks whether the input object is of type 'enumerate'.
@@ -327,7 +402,7 @@ def is_enumerate(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'enumerate', False otherwise.
     """
-    return isinstance(obj, enumerate)
+    return is_instance(obj, enumerate)
 def is_zip(obj:any) -> bool:
     """
     Checks whether the input object is of type 'zip'.
@@ -338,7 +413,7 @@ def is_zip(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'zip', False otherwise.
     """
-    return isinstance(obj, zip)
+    return is_instance(obj, zip)
 def is_filter(obj:any) -> bool:
     """
     Checks whether the input object is of type 'filter'.
@@ -349,7 +424,7 @@ def is_filter(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'filter', False otherwise.
     """
-    return isinstance(obj, filter)
+    return is_instance(obj, filter)
 def is_map(obj:any) -> bool:
     """
     Checks whether the input object is of type 'map'.
@@ -360,7 +435,7 @@ def is_map(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'map', False otherwise.
     """
-    return isinstance(obj, map)
+    return is_instance(obj, map)
 def is_property(obj:any) -> bool:
     """
     Checks whether the input object is of type 'property'.
@@ -371,7 +446,7 @@ def is_property(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'property', False otherwise.
     """
-    return isinstance(obj, property)
+    return is_instance(obj, property)
 
 
 def is_slice(obj:any) -> bool:
@@ -384,7 +459,7 @@ def is_slice(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'slice', False otherwise.
     """
-    return isinstance(obj, slice)
+    return is_instance(obj, slice)
 
 
 def is_super(obj:any) -> bool:
@@ -397,7 +472,7 @@ def is_super(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'super', False otherwise.
     """
-    return isinstance(obj, super)
+    return is_instance(obj, super)
 
 
 def is_type(obj:any) -> bool:
@@ -410,7 +485,7 @@ def is_type(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'type', False otherwise.
     """
-    return isinstance(obj, type)
+    return is_instance(obj, type)
 
 
 def is_Exception(obj:any) -> bool:
@@ -423,7 +498,7 @@ def is_Exception(obj:any) -> bool:
     Returns:
         bool: True if the object is of type 'Exception', False otherwise.
     """
-    return isinstance(obj, Exception)
+    return is_instance(obj, Exception)
 
 
 def is_none(obj:any) -> bool:
@@ -470,7 +545,7 @@ def is_str_convertible_dict(obj:any) -> bool:
     """
     import json
 
-    if isinstance(obj, str):
+    if is_instance(obj, str):
         try:
             json.loads(obj)
             return True
@@ -509,7 +584,7 @@ def make_list_lower(ls: list) -> list:
     Returns:
         list: The list with all strings converted to lowercase.
     """
-    return [item.lower() if isinstance(item, str) else item for item in ls]
+    return [item.lower() if is_instance(item, str) else item for item in ls]
 
 
 def make_float(obj:Union[str,float,int]) -> float:
@@ -546,14 +621,14 @@ def make_bool(obj: Union[bool, int, str]) -> Union[bool, str]:
         make_bool("0")    -> False
         make_bool(2)      -> 2
     """
-    if isinstance(obj, bool):
+    if is_instance(obj, bool):
         return obj
-    if isinstance(obj, int):
+    if is_instance(obj, int):
         if obj == 0:
             return False
         if obj == 1:
             return True
-    if isinstance(obj, str):
+    if is_instance(obj, str):
         if obj.lower() in ['0', "false"]:
             return False
         if obj.lower() in ['1', "true"]:
@@ -626,7 +701,7 @@ def det_bool_F(obj: (tuple or list or bool) = False):
     Returns:
         bool: True if the object is a boolean False value, False otherwise.
     """
-    if isinstance(obj, bool):
+    if is_instance(obj, bool):
         return obj
     return all(obj)
 def det_bool_T(obj: (tuple or list or bool) = False):
@@ -639,7 +714,7 @@ def det_bool_T(obj: (tuple or list or bool) = False):
     Returns:
         bool: True if the object is a boolean True value, False otherwise.
     """
-    if isinstance(obj, bool):
+    if is_instance(obj, bool):
         return obj 
     return any(obj)
 def T_or_F_obj_eq(event: any = '', obj: any = ''):
@@ -700,14 +775,6 @@ def convert_to_number(value):
     if is_number(value_str):
         return float(value_str) if '.' in value_str else int(value_str)
     return value_str
-def is_number(s):
-    if s:
-        try:
-            float(s)
-            return True
-        except:
-            return False
-    return False
 
 def makeInt(obj):
     if is_number(obj):
@@ -721,6 +788,71 @@ def str_lower(obj):
         print(f"{e}")
     return obj
 
+def get_bool_response(bool_response,json_data):
+    if not is_instance(bool_response,bool):
+        try:
+            bool_response = json_data.get(bool_response) in [None,'',[],"",{}]
+        except:
+            pass       
+    return bool_response
+def if_true_get_string(data, key):
+    return key if data.get(key) else None
+def find_for_string(string, parts):
+    return [part for part in parts if string.lower() in str(part).lower()]
+
+
+def is_strings_in_string(strings, parts):
+    strings = make_list(strings)
+    for string in strings:
+        parts = find_for_string(string, parts)
+        if not parts:
+            return []
+    return parts
+
+
+
+
+
+def get_alphabet_str():
+  return 'abcdefghijklmnopqrstuvwxyz'
+def get_alphabet_upper_str():
+  alphabet_str = get_alphabet_str()
+  return alphabet_str.upper()
+def get_alphabet_comp_str():
+  return get_alphabet_str() + get_alphabet_upper_str()
+
+def get_alphabet():
+  alphabet_str = get_alphabet_str()
+  return break_string(alphabet_str)
+def get_alphabet_upper():
+  alphabet_upper_str = get_alphabet_upper_str()
+  return break_string(alphabet_upper_str)
+def get_alphabet_comp():
+  alphabet_comp_str = get_alphabet_comp_str()
+  return break_string(alphabet_comp_str)
+
+def get_numbers_str():
+  return '0123457890'
+def get_numbers_int():
+  numbers_str = get_numbers_str()
+  return [int(number) for number in numbers_str]
+
+
+def get_numbers():
+  numbers_str = get_numbers_str()
+  return break_string(numbers_str)
+def get_numbers_comp():
+  numbers_str = get_numbers()
+  numbers_int = get_numbers_int()
+  return numbers_str + numbers_int
+def break_string(string):
+  string_str = str(string)
+  return list(string_str)
+def is_any_instance(value):
+    for each in [dict, list, int, float]:
+        if is_instance(value, each):
+            return True
+
 # Function: is_number
 # Function: is_str
 # Function: is_int
